@@ -4,23 +4,30 @@
 #'  programming interface (API) key
 #'
 #' @rdname getDataCM
+#' @family GET functions
 #' @author Kauê de Sousa
 #' @param project a character for the project id
 #' @param as.data.frame logical, to return a data frame
-#' @param ... additional arguments passed to methods
+#' @param ... additional arguments passed to methods. See details
 #' @inheritParams getProjectsCM
-#' @return An object of class 'CM_list' or a data.frame with the 
+#' @return An object of class 'CM_list' or a data.frame with class "CM_df" with the 
 #' variables:
 #' \item{id}{the participant's package id}
 #' \item{moment}{the data collection moment}
 #' \item{variable}{the variable name}
 #' \item{value}{the value for each variable}
+#' @details 
+#' Additional arguments: 
+#' 
+#' \code{server}: a character to select from which server the data will be retrieved, either 
+#'  "prodution" (the default) or "testing"
+#' 
 #' @examples
 #' \dontrun{
 #' 
 #' # This function will not work without an API key  
 #' # the user API key can be obtained once a free ClimMob account 
-#' # is created via https://climmob.net/climmob3/
+#' # is created via https://climmob.net/
 #' 
 #' my_key <- "add_your_key"
 #' my_project <- "my_climmob_project"
@@ -29,21 +36,39 @@
 #' 
 #' }
 #' 
-#' @seealso \code{\link{getProjectsCM}}
-#' @importFrom httr accept_json content GET
+#' @seealso ClimMob website \url{https://climmob.net/}
+#' @importFrom httr accept_json content RETRY
 #' @importFrom jsonlite fromJSON
-#' @importFrom tibble as_tibble
 #' @export
 getDataCM <- function(key = NULL, 
                       project = NULL, 
                       as.data.frame = TRUE, ...){
   
-  url <- "https://climmob.net/climmob3/api/readDataOfProject?Body={}&Apikey={}"
+  dots <- list(...)
+  server <- dots[["server"]]
   
-  cmdata <- httr::GET(url = url,
-                      query = list(Body = paste0('{"project_cod":"', project, '"}'),
-                                   Apikey = key),
-                      httr::accept_json())
+  if (is.null(server)) {
+    server <- "production"
+  }
+  
+  if (server == "production") {
+    
+    url <- "https://climmob.net/climmob3/api/readDataOfProject?Body={}&Apikey={}"
+    
+  }
+  
+  if (server == "testing") {
+    
+    url <- "https://testing.climmob.net/climmob3/api/readDataOfProject?Body={}&Apikey={}"
+    
+  }
+  
+  cmdata <- httr::RETRY(verb = "GET", 
+                        url = url,
+                        query = list(Body = paste0('{"project_cod":"', project, '"}'),
+                                    Apikey = key),
+                        httr::accept_json(), 
+                        terminate_on = c(403, 404))
   
   cmdata <- httr::content(cmdata, as = "text")
   
@@ -61,7 +86,6 @@ getDataCM <- function(key = NULL,
   # if required, coerce to a data frame
   if (isTRUE(as.data.frame)) {
     cmdata <- as.data.frame(x = cmdata, ...)
-    cmdata <- tibble::as_tibble(cmdata)
   }
   
   return(cmdata)
